##
## File:        make.runJava
## Package:     Babel regression checks
## Revision:    $Revision: 4634 $
## Modified:    $Date: 2005-05-11 14:22:11 -0700 (Wed, 11 May 2005) $
## Description: automake makefile for run regression tests
##
## Copyright (c) 2000-2002, The Regents of the University of Calfornia.
## Produced at the Lawrence Livermore National Laboratory.
## Written by the Components Team <components@llnl.gov>
## UCRL-CODE-2002-054
## All rights reserved.
##
## This file is part of Babel. For more information, see
## http://www.llnl.gov/CASC/components/. Please read the COPYRIGHT file
## for Our Notice and the LICENSE file for the GNU Lesser General Public
## License.
##
## This program is free software; you can redistribute it and/or modify it
## under the terms of the GNU Lesser General Public License (as published by
## the Free Software Foundation) version 2.1 dated February 1999.
##
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the IMPLIED WARRANTY OF
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the terms and
## conditions of the GNU Lesser General Public License for more details.
##
## You should have recieved a copy of the GNU Lesser General Public License
## along with this program; if not, write to the Free Software Foundation,
## Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA





OUTPUTSIDL=$(srcdir)/../../output/output.sidl

if SUPPORT_JAVA
check_SCRIPTS = runJava2C.sh runJava2Cxx.sh runJava2UCxx.sh \
	runJava2F77.sh runJava2F90.sh runJava2Java.sh

check_LTLIBRARIES = libClient.la
endif

VERSION=@VERSION@
BABELDIR    = $(top_builddir)/bin
INCLUDEDIR  = $(top_builddir)/runtime/sidl
INCLUDEDIR2 = .
LIBSIDL     = $(top_builddir)/runtime/sidl/libsidl.la
LIBSYNC     = ../../output/libC/libOutput.la
PUREBABELGEN = $(STUBSRCS) $(IORHDRS)
CLEANFILES = $(PUREBABELGEN) $(EXTRACLEAN) babel-temp babel-stamp \
	stamp-installcheck babel.make.package java-temp java-stamp \
	babel.make.depends

libClient_la_SOURCES      = $(PUREBABELGEN) $(SOURCE_EXTRAS)
libClient_la_LIBADD       = $(LIBSYNC) $(LIBSIDL)
libClient_la_LDFLAGS      = -no-undefined -rpath `pwd`/.libs \
			    -release $(VERSION)

EXTRA_DIST = $(TESTFILE) 
AM_CPPFLAGS   = -I. -I$(INCLUDEDIR) -I$(INCLUDEDIR2) $(JNI_INCLUDES)

$(PUREBABELGEN) : babel-stamp
	@if test -f $@; then \
	  touch $@; \
	else \
	  $(MAKE) $(AM_MAKEFLAGS) babel-stamp; \
	fi

CP = $(top_builddir)/lib/sidl-$(VERSION).jar:$(top_builddir)/lib/sidlstubs/Java/sidlstub_$(VERSION).jar
if SUPPORT_CYGWIN
  CLASSPATH = `cygpath --path --windows "$(CP):."`
else
  CLASSPATH = $(CP):.
endif
JAVAC_FLAGS = -g -d . -classpath "$(CLASSPATH)"

babel-stamp: $(SIDLFILE) $(TESTFILE) $(OUTPUTSIDL) $(SOURCE_EXTRAS)
	@rm -f babel-temp
	@touch babel-temp
	$(SHELL) $(BABELDIR)/babel --client=java --exclude-external \
		--suppress-timestamp $(BABELEXTRA) $(SIDLFILE) $(OUTPUTSIDL)
	rm -f libClient.scl
	echo "<?xml version=\"1.0\" ?>" > libClient.scl
	echo "<scl>" >> libClient.scl
	if test `uname` = "Darwin"; then \
	  scope="global"; \
	else \
	  scope="local"; \
	fi ; \
	echo "  <library uri=\""`pwd`"/libClient.la\" scope=\"$$scope\" resolution=\"lazy\" >" >> libClient.scl
	grep __register $(STUBSRCS) /dev/null | awk 'BEGIN {FS=":"} { print $$1}' | sort -u | sed -e 's/_jniStub.c//g' -e 's/_/./g' | awk ' { printf "    <class name=\"%s\" desc=\"java\" />\n", $$1 }' >> libClient.scl
	echo "  </library>" >> libClient.scl
	echo "</scl>" >> libClient.scl
	@mv -f babel-temp babel-stamp

java-stamp: babel-stamp
	@rm -f java-temp
	@touch java-temp
	if test "X$(srcdir)" = "X."; then				    \
	  $(JAVAC) $(JAVAC_FLAGS) `find . \( -name "*.java" -print \) -o \( -name .svn -prune \)`;	    \
	else								    \
	  $(JAVAC) $(JAVAC_FLAGS) `find $(srcdir) . \( -name "*.java" -print \) -o \( -name .svn -prune \)`; \
	fi
	@mv -f java-temp java-stamp
	

clean-local:
	rm -f *.a *.so *.scl *.class 
	rm -rf `find * \( -name .svn -prune \) -o \( -type d -print \)`
	test "X$(srcdir)" = "X." || rm -f babel.make \
		$(check_SCRIPTS)

check-local:
	@if test -f stamp-installcheck; then            \
	  echo $(MAKE) $(AM_MAKEFLAGS) clean;           \
	  $(MAKE) $(AM_MAKEFLAGS) clean;                \
	fi
	$(MAKE) $(AM_MAKEFLAGS)				\
	  $(check_LTLIBRARIES) $(check_PROGRAMS) $(check_SCRIPTS) \
	  java-stamp

installcheck-local:
	@if test ! -f stamp-installcheck; then          \
	  echo $(MAKE) $(AM_MAKEFLAGS) clean;           \
	  $(MAKE) $(AM_MAKEFLAGS) clean;                \
	fi
	$(MAKE) $(AM_MAKEFLAGS)                         \
	  BABELDIR=$(bindir)				\
	  INCLUDEDIR=$(includedir)	                 \
	  INCLUDEDIR2=$(exec_prefix)/include            \
	  CP=$(libdir)/sidl-$(VERSION).jar:$(libdir)/sidlstub_$(VERSION).jar \
	  LIBSIDL=$(libdir)/libsidl.la $(check_PROGRAMS) $(check_SCRIPTS) $(check_LTLIBRARIES) java-stamp
	touch stamp-installcheck

# Make sure Makefile.in is newer than babel.make
dist-hook:
	touch -c $(distdir)/Makefile.in
